OC.L10N.register(
    "comments",
    {
    "Comments" : "Commentarios",
    "You commented" : "Tu commentava",
    "%1$s commented" : "%1$s commentava",
    "{author} commented" : "{author} commentava",
    "You commented on %1$s" : "Tu commentava in %1$s",
    "You commented on {file}" : "Tu commentava in {file}",
    "%1$s commented on %2$s" : "%1$s commentava in %2$s",
    "{author} commented on {file}" : "{author} commentava in {file}",
    "<strong>Comments</strong> for files" : "<strong>Commentarios</strong> pro files",
    "Edit comment" : "Modificar commentario",
    "Delete comment" : "Deler commentario",
    "No comments yet, start the conversation!" : "Il ha nulle commentarios ancora, initia le conversation!",
    "_%n unread comment_::_%n unread comments_" : ["%n commentario non legite","%n commentarios non legite"],
    "Comment" : "Commentario",
    "{user} mentioned you in a comment on “{file}”" : "{user} mentionava tu in un commentario in “{file}”"
},
"nplurals=2; plural=(n != 1);");
